Class: Google::Cloud::TelcoAutomation::V1::ApplyDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for ApplyDeployment. The resources in given deployment gets applied to Orchestration Cluster. A new revision is created when a deployment is applied.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the deployment to apply to orchestration cluster.

Returns:

  • (::String)

    Required. The name of the deployment to apply to orchestration cluster.



1057
1058
1059
1060
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1057

class ApplyDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end