Class: Google::Cloud::TelcoAutomation::V1::Deployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Deployment contains a collection of YAML files (This collection is also known as package) that can to applied on an orchestration cluster (GKE cluster with TNA addons) or a workload cluster.

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Deployment creation time.

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#deployment_level::Google::Cloud::TelcoAutomation::V1::DeploymentLevel (readonly)

Returns Output only. Attributes to where the deployment can inflict changes. The value can only be [SINGLE_DEPLOYMENT, MULTI_DEPLOYMENT].

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#display_name::String

Returns Optional. Human readable name of a Deployment.

Returns:

  • (::String)

    Optional. Human readable name of a Deployment.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#files::Array<::Google::Cloud::TelcoAutomation::V1::File>

Returns Optional. Files present in a deployment. When invoking UpdateDeployment API, only the modified files should be included in this. Files that are not included in the update of a deployment will not be changed.

Returns:

  • (::Array<::Google::Cloud::TelcoAutomation::V1::File>)

    Optional. Files present in a deployment. When invoking UpdateDeployment API, only the modified files should be included in this. Files that are not included in the update of a deployment will not be changed.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels are key-value attributes that can be set on a deployment resource by the user.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels are key-value attributes that can be set on a deployment resource by the user.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#name::String

Returns The name of the deployment.

Returns:

  • (::String)

    The name of the deployment.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#repository::String (readonly)

Returns Output only. Name of the repository where the deployment package files are stored.

Returns:

  • (::String)

    Output only. Name of the repository where the deployment package files are stored.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#revision_create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp that the revision was created.

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#revision_id::String (readonly)

Returns Output only. Immutable. The revision ID of the deployment. A new revision is committed whenever a change in deployment is applied.

Returns:

  • (::String)

    Output only. Immutable. The revision ID of the deployment. A new revision is committed whenever a change in deployment is applied.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#rollback_support::Boolean (readonly)

Returns Output only. Indicates if the deployment can be rolled back, exported from public blueprint.

Returns:

  • (::Boolean)

    Output only. Indicates if the deployment can be rolled back, exported from public blueprint.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#source_blueprint_revision::String

Returns Required. The blueprint revision from which this deployment was created.

Returns:

  • (::String)

    Required. The blueprint revision from which this deployment was created.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#source_provider::String (readonly)

Returns Output only. Source provider is the author of a public blueprint, from which this deployment is created.

Returns:

  • (::String)

    Output only. Source provider is the author of a public blueprint, from which this deployment is created.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#state::Google::Cloud::TelcoAutomation::V1::Deployment::State (readonly)

Returns Output only. State of the deployment (DRAFT, APPLIED, DELETING).

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the deployment was updated.

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end

#workload_cluster::String

Returns Optional. Immutable. The WorkloadCluster on which to create the Deployment. This field should only be passed when the deployment_level of the source blueprint specifies deployments on workload clusters e.g. WORKLOAD_CLUSTER_DEPLOYMENT.

Returns:

  • (::String)

    Optional. Immutable. The WorkloadCluster on which to create the Deployment. This field should only be passed when the deployment_level of the source blueprint specifies deployments on workload clusters e.g. WORKLOAD_CLUSTER_DEPLOYMENT.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 345

class Deployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State defines which state the current deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A deployment starts in DRAFT state. All edits are made in DRAFT state. A
    # deployment opened for editing after applying will be in draft state,
    # while its prevision revision will be its current applied version.
    DRAFT = 1

    # This state means that the contents (YAML files containing kubernetes
    # resources) of the deployment have been applied to an Orchestration or
    # Workload Cluster. A revision is created when a deployment is applied.
    # This revision will represent the latest view of what is applied on the
    # cluster until the deployment is modified and applied again, which will
    # create a new revision.
    APPLIED = 2

    # A deployment in DELETING state has been marked for deletion. Its
    # deletion status can be queried using `ComputeDeploymentStatus` API. No
    # updates are allowed to a deployment in DELETING state.
    DELETING = 3
  end
end