Module: Google::Cloud::TelcoAutomation::V1::DeploymentLevel

Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

DeploymentLevel of a blueprint signifies where the blueprint will be applied.

Constant Summary collapse

DEPLOYMENT_LEVEL_UNSPECIFIED =

Default unspecified deployment level.

0
HYDRATION =

Blueprints at HYDRATION level cannot be used to create a Deployment (A user cannot manually initate deployment of these blueprints on orchestration or workload cluster). These blueprints stay in a user's private catalog and are configured and deployed by TNA automation.

1
SINGLE_DEPLOYMENT =

Blueprints at SINGLE_DEPLOYMENT level can be a) Modified in private catalog. b) Used to create a deployment on orchestration cluster by the user, once approved.

2
MULTI_DEPLOYMENT =

Blueprints at MULTI_DEPLOYMENT level can be a) Modified in private catalog. b) Used to create a deployment on orchestration cluster which will create further hydrated deployments.

3
WORKLOAD_CLUSTER_DEPLOYMENT =

Blueprints at WORKLOAD_CLUSTER_DEPLOYMENT level can be a) Modified in private catalog. b) Used to create a deployment on workload cluster by the user, once approved.

4