Class: Google::Cloud::TelcoAutomation::V1::DiscardBlueprintChangesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for DiscardBlueprintChanges.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the blueprint of which changes are being discarded.

Returns:

  • (::String)

    Required. The name of the blueprint of which changes are being discarded.



821
822
823
824
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 821

class DiscardBlueprintChangesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end