Class: Google::Cloud::TelcoAutomation::V1::File

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

File represents a yaml file present in a blueprint's package.

Instance Attribute Summary collapse

Instance Attribute Details

#content::String

Returns Optional. The contents of a file in string format.

Returns:

  • (::String)

    Optional. The contents of a file in string format.



1345
1346
1347
1348
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1345

class File
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deleted::Boolean

Returns Optional. Signifies whether a file is marked for deletion.

Returns:

  • (::Boolean)

    Optional. Signifies whether a file is marked for deletion.



1345
1346
1347
1348
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1345

class File
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#editable::Boolean

Returns Optional. Indicates whether changes are allowed to a file. If the field is not set, the file cannot be edited.

Returns:

  • (::Boolean)

    Optional. Indicates whether changes are allowed to a file. If the field is not set, the file cannot be edited.



1345
1346
1347
1348
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1345

class File
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String

Returns Required. Path of the file in package. e.g. gdce/v1/cluster.yaml.

Returns:

  • (::String)

    Required. Path of the file in package. e.g. gdce/v1/cluster.yaml



1345
1346
1347
1348
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1345

class File
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end