Class: Google::Cloud::TelcoAutomation::V1::GetBlueprintRequest
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::GetBlueprintRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Request object for GetBlueprint.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::TelcoAutomation::V1::BlueprintView
Optional.
Instance Attribute Details
#name ⇒ ::String
Required. The name of the blueprint. Case 1: If the name provided in the request is {blueprint_id}@{revision_id}, then the revision with revision_id will be returned. Case 2: If the name provided in the request is {blueprint}, then the current state of the blueprint is returned.
666 667 668 669 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 666 class GetBlueprintRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::TelcoAutomation::V1::BlueprintView
Returns Optional. Defines the type of view of the blueprint. When field is not present BLUEPRINT_VIEW_BASIC is considered as default.
666 667 668 669 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 666 class GetBlueprintRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |