Class: Google::Cloud::TelcoAutomation::V1::HydratedDeployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

A collection of kubernetes yaml files which are deployed on a Workload Cluster. Hydrated Deployments are created by TNA intent based automation.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#files::Array<::Google::Cloud::TelcoAutomation::V1::File>

Returns Optional. File contents of a hydrated deployment. When invoking UpdateHydratedBlueprint API, only the modified files should be included in this. Files that are not included in the update of a hydrated deployment will not be changed.

Returns:

  • (::Array<::Google::Cloud::TelcoAutomation::V1::File>)

    Optional. File contents of a hydrated deployment. When invoking UpdateHydratedBlueprint API, only the modified files should be included in this. Files that are not included in the update of a hydrated deployment will not be changed.



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 401

class HydratedDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State defines which state the current hydrated deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A hydrated deployment starts in DRAFT state. All edits are made in DRAFT
    # state.
    DRAFT = 1

    # When the edit is applied, the hydrated deployment moves to APPLIED
    # state. No changes can be made once a hydrated deployment is applied.
    APPLIED = 2
  end
end

#name::String (readonly)

Returns Output only. The name of the hydrated deployment.

Returns:

  • (::String)

    Output only. The name of the hydrated deployment.



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 401

class HydratedDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State defines which state the current hydrated deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A hydrated deployment starts in DRAFT state. All edits are made in DRAFT
    # state.
    DRAFT = 1

    # When the edit is applied, the hydrated deployment moves to APPLIED
    # state. No changes can be made once a hydrated deployment is applied.
    APPLIED = 2
  end
end

#state::Google::Cloud::TelcoAutomation::V1::HydratedDeployment::State (readonly)

Returns Output only. State of the hydrated deployment (DRAFT, APPLIED).

Returns:



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 401

class HydratedDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State defines which state the current hydrated deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A hydrated deployment starts in DRAFT state. All edits are made in DRAFT
    # state.
    DRAFT = 1

    # When the edit is applied, the hydrated deployment moves to APPLIED
    # state. No changes can be made once a hydrated deployment is applied.
    APPLIED = 2
  end
end

#workload_cluster::String (readonly)

Returns Output only. WorkloadCluster identifies which workload cluster will the hydrated deployment will be deployed on.

Returns:

  • (::String)

    Output only. WorkloadCluster identifies which workload cluster will the hydrated deployment will be deployed on.



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 401

class HydratedDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State defines which state the current hydrated deployment is in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # A hydrated deployment starts in DRAFT state. All edits are made in DRAFT
    # state.
    DRAFT = 1

    # When the edit is applied, the hydrated deployment moves to APPLIED
    # state. No changes can be made once a hydrated deployment is applied.
    APPLIED = 2
  end
end