Module: Google::Cloud::TelcoAutomation::V1::HydratedDeployment::State

Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

State defines which state the current hydrated deployment is in.

Constant Summary collapse

STATE_UNSPECIFIED =

Unspecified state.

0
DRAFT =

A hydrated deployment starts in DRAFT state. All edits are made in DRAFT state.

1
APPLIED =

When the edit is applied, the hydrated deployment moves to APPLIED state. No changes can be made once a hydrated deployment is applied.

2