Class: Google::Cloud::TelcoAutomation::V1::ListBlueprintsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for ListBlueprints.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filtering only supports equality on blueprint state. It should be in the form: "state = DRAFT". OR operator can be used to get response for multiple states. e.g. "state = DRAFT OR state = PROPOSED".

Returns:

  • (::String)

    Optional. Filtering only supports equality on blueprint state. It should be in the form: "state = DRAFT". OR operator can be used to get response for multiple states. e.g. "state = DRAFT OR state = PROPOSED".



701
702
703
704
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 701

class ListBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of blueprints to return per page.

Returns:

  • (::Integer)

    Optional. The maximum number of blueprints to return per page.



701
702
703
704
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 701

class ListBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The page token, received from a previous ListBlueprints call. It can be provided to retrieve the subsequent page.

Returns:

  • (::String)

    Optional. The page token, received from a previous ListBlueprints call. It can be provided to retrieve the subsequent page.



701
702
703
704
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 701

class ListBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The name of parent orchestration cluster resource. Format should be - "projects/{project_id}/locations/{location_name}/orchestrationClusters/{orchestration_cluster}".

Returns:

  • (::String)

    Required. The name of parent orchestration cluster resource. Format should be - "projects/{project_id}/locations/{location_name}/orchestrationClusters/{orchestration_cluster}".



701
702
703
704
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 701

class ListBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end