Class: Google::Cloud::TelcoAutomation::V1::ListBlueprintsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::ListBlueprintsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Response object for ListBlueprints.
Instance Attribute Summary collapse
-
#blueprints ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Blueprint>
The list of requested blueprints.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#blueprints ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Blueprint>
Returns The list of requested blueprints.
714 715 716 717 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 714 class ListBlueprintsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
714 715 716 717 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 714 class ListBlueprintsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |