Class: Google::Cloud::TelcoAutomation::V1::ListDeploymentRevisionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

List of deployment revisions for a given deployment.

Instance Attribute Summary collapse

Instance Attribute Details

#deployments::Array<::Google::Cloud::TelcoAutomation::V1::Deployment>

Returns The revisions of the deployment.

Returns:



989
990
991
992
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 989

class ListDeploymentRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



989
990
991
992
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 989

class ListDeploymentRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end