Class: Google::Cloud::TelcoAutomation::V1::ListDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::ListDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Response object for ListDeployments.
Instance Attribute Summary collapse
-
#deployments ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Deployment>
The list of requested deployments.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#deployments ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Deployment>
Returns The list of requested deployments.
960 961 962 963 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 960 class ListDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
960 961 962 963 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 960 class ListDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |