Class: Google::Cloud::TelcoAutomation::V1::ListHydratedDeploymentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Response object for ListHydratedDeployments.

Instance Attribute Summary collapse

Instance Attribute Details

#hydrated_deployments::Array<::Google::Cloud::TelcoAutomation::V1::HydratedDeployment>

Returns The list of hydrated deployments.

Returns:



1165
1166
1167
1168
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1165

class ListHydratedDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



1165
1166
1167
1168
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1165

class ListHydratedDeploymentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end