Class: Google::Cloud::TelcoAutomation::V1::ListOrchestrationClustersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::ListOrchestrationClustersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Message for response to listing OrchestrationClusters.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#orchestration_clusters ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::OrchestrationCluster>
The list of OrchestrationCluster.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
452 453 454 455 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 452 class ListOrchestrationClustersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#orchestration_clusters ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::OrchestrationCluster>
Returns The list of OrchestrationCluster.
452 453 454 455 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 452 class ListOrchestrationClustersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
452 453 454 455 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 452 class ListOrchestrationClustersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |