Class: Google::Cloud::TelcoAutomation::V1::ListPublicBlueprintsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for ListPublicBlueprints.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



845
846
847
848
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 845

class ListPublicBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



845
846
847
848
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 845

class ListPublicBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value of public blueprint. Format should be - "projects/{project_id}/locations/{location_name}".

Returns:

  • (::String)

    Required. Parent value of public blueprint. Format should be - "projects/{project_id}/locations/{location_name}".



845
846
847
848
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 845

class ListPublicBlueprintsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end