Class: Google::Cloud::TelcoAutomation::V1::ListPublicBlueprintsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Response object for ListPublicBlueprints.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String (readonly)

Output only. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Output only. A token identifying a page of results the server should return.



858
859
860
861
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 858

class ListPublicBlueprintsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#public_blueprints::Array<::Google::Cloud::TelcoAutomation::V1::PublicBlueprint>

Returns The list of public blueprints to return.

Returns:



858
859
860
861
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 858

class ListPublicBlueprintsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end