Class: Google::Cloud::TelcoAutomation::V1::ManagementConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Configuration of the cluster management

Instance Attribute Summary collapse

Instance Attribute Details

#full_management_config::Google::Cloud::TelcoAutomation::V1::FullManagementConfig

Returns Configuration of the full (Autopilot) cluster management. Full cluster management is a preview feature.

Note: The following fields are mutually exclusive: full_management_config, standard_management_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::TelcoAutomation::V1::FullManagementConfig)

    Configuration of the full (Autopilot) cluster management. Full cluster management is a preview feature.

    Note: The following fields are mutually exclusive: full_management_config, standard_management_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



1204
1205
1206
1207
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1204

class ManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#standard_management_config::Google::Cloud::TelcoAutomation::V1::StandardManagementConfig

Returns Configuration of the standard (GKE) cluster management

Note: The following fields are mutually exclusive: standard_management_config, full_management_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::TelcoAutomation::V1::StandardManagementConfig)

    Configuration of the standard (GKE) cluster management

    Note: The following fields are mutually exclusive: standard_management_config, full_management_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



1204
1205
1206
1207
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1204

class ManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end