Class: Google::Cloud::TelcoAutomation::V1::MasterAuthorizedNetworksConfig::CidrBlock

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

CidrBlock contains an optional name and one CIDR block.

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_block::String

Returns Optional. cidr_block must be specified in CIDR notation when using master_authorized_networks_config. Currently, the user could still use the deprecated man_block field, so this field is currently optional, but will be required in the future.

Returns:

  • (::String)

    Optional. cidr_block must be specified in CIDR notation when using master_authorized_networks_config. Currently, the user could still use the deprecated man_block field, so this field is currently optional, but will be required in the future.



1324
1325
1326
1327
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1324

class CidrBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Optional. display_name is an optional field for users to identify CIDR blocks.

Returns:

  • (::String)

    Optional. display_name is an optional field for users to identify CIDR blocks.



1324
1325
1326
1327
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1324

class CidrBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end