Class: Google::Cloud::TelcoAutomation::V1::NFDeployStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Deployment status of NFDeploy.

Instance Attribute Summary collapse

Instance Attribute Details

#ready_nfs::Integer (readonly)

Returns Output only. Total number of NFs targeted by this deployment with a Ready Condition set.

Returns:

  • (::Integer)

    Output only. Total number of NFs targeted by this deployment with a Ready Condition set.



1391
1392
1393
1394
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1391

class NFDeployStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sites::Array<::Google::Cloud::TelcoAutomation::V1::NFDeploySiteStatus> (readonly)

Returns Output only. Per-Site Status.

Returns:



1391
1392
1393
1394
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1391

class NFDeployStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#targeted_nfs::Integer (readonly)

Returns Output only. Total number of NFs targeted by this deployment.

Returns:

  • (::Integer)

    Output only. Total number of NFs targeted by this deployment



1391
1392
1393
1394
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1391

class NFDeployStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end