Class: Google::Cloud::TelcoAutomation::V1::OrchestrationCluster

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Orchestration cluster represents a GKE cluster with config controller and TNA specific components installed on it.

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Create time stamp.

Returns:



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels as key value pairs.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels as key value pairs.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#management_config::Google::Cloud::TelcoAutomation::V1::ManagementConfig

Returns Management configuration of the underlying GKE cluster.

Returns:



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#name::String

Returns Name of the orchestration cluster. The name of orchestration cluster cannot be more than 24 characters.

Returns:

  • (::String)

    Name of the orchestration cluster. The name of orchestration cluster cannot be more than 24 characters.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#state::Google::Cloud::TelcoAutomation::V1::OrchestrationCluster::State (readonly)

Returns Output only. State of the Orchestration Cluster.

Returns:



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#tna_version::String (readonly)

Returns Output only. Provides the TNA version installed on the cluster.

Returns:

  • (::String)

    Output only. Provides the TNA version installed on the cluster.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Update time stamp.

Returns:



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 48

class OrchestrationCluster
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states that the Orchestration Cluster can be in.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # OrchestrationCluster is being created.
    CREATING = 1

    # OrchestrationCluster has been created and is ready for use.
    ACTIVE = 2

    # OrchestrationCluster is being deleted.
    DELETING = 3

    # OrchestrationCluster encountered an error and is in an indeterministic
    # state. User can still initiate a delete operation on this state.
    FAILED = 4
  end
end