Class: Google::Cloud::TelcoAutomation::V1::SearchBlueprintRevisionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Response object for SearchBlueprintRevisions.

Instance Attribute Summary collapse

Instance Attribute Details

#blueprints::Array<::Google::Cloud::TelcoAutomation::V1::Blueprint>

Returns The list of requested blueprint revisions.

Returns:



812
813
814
815
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 812

class SearchBlueprintRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



812
813
814
815
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 812

class SearchBlueprintRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end