Class: Google::Cloud::TelcoAutomation::V1::StandardManagementConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Configuration of the standard (GKE) cluster management.

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_cidr_block::String

Returns Optional. The IP address range for the cluster pod IPs. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.

Returns:

  • (::String)

    Optional. The IP address range for the cluster pod IPs. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cluster_named_range::String

Returns Optional. The name of the existing secondary range in the cluster's subnetwork to use for pod IP addresses. Alternatively, cluster_cidr_block can be used to automatically create a GKE-managed one.

Returns:

  • (::String)

    Optional. The name of the existing secondary range in the cluster's subnetwork to use for pod IP addresses. Alternatively, cluster_cidr_block can be used to automatically create a GKE-managed one.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#master_authorized_networks_config::Google::Cloud::TelcoAutomation::V1::MasterAuthorizedNetworksConfig

Returns Optional. Master Authorized Network that supports multiple CIDR blocks. Allows access to the k8s master from multiple blocks. It cannot be set at the same time with the field man_block.

Returns:



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#master_ipv4_cidr_block::String

Returns Optional. The /28 network that the masters will use. It should be free within the network.

Returns:

  • (::String)

    Optional. The /28 network that the masters will use. It should be free within the network.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#network::String

Returns Optional. Name of the VPC Network to put the GKE cluster and nodes in. The VPC will be created if it doesn't exist.

Returns:

  • (::String)

    Optional. Name of the VPC Network to put the GKE cluster and nodes in. The VPC will be created if it doesn't exist.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#services_cidr_block::String

Returns Optional. The IP address range for the cluster service IPs. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.

Returns:

  • (::String)

    Optional. The IP address range for the cluster service IPs. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#services_named_range::String

Returns Optional. The name of the existing secondary range in the cluster's subnetwork to use for service ClusterIPs. Alternatively, services_cidr_block can be used to automatically create a GKE-managed one.

Returns:

  • (::String)

    Optional. The name of the existing secondary range in the cluster's subnetwork to use for service ClusterIPs. Alternatively, services_cidr_block can be used to automatically create a GKE-managed one.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subnet::String

Returns Optional. Specifies the subnet that the interface will be part of. Network key must be specified and the subnet must be a subnetwork of the specified network.

Returns:

  • (::String)

    Optional. Specifies the subnet that the interface will be part of. Network key must be specified and the subnet must be a subnetwork of the specified network.



1252
1253
1254
1255
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1252

class StandardManagementConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end