Class: Google::Cloud::TelcoAutomation::V1::UpdateBlueprintRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for UpdateBlueprint.

Instance Attribute Summary collapse

Instance Attribute Details

#blueprint::Google::Cloud::TelcoAutomation::V1::Blueprint

Returns Required. The blueprint to update.

Returns:



649
650
651
652
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 649

class UpdateBlueprintRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. Update mask is used to specify the fields to be overwritten in the blueprint resource by the update.

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. Update mask is used to specify the fields to be overwritten in the blueprint resource by the update.



649
650
651
652
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 649

class UpdateBlueprintRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end