Class: Google::Cloud::TelcoAutomation::V1::UpdateDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb

Overview

Request object for UpdateDeployment.

Instance Attribute Summary collapse

Instance Attribute Details

#deployment::Google::Cloud::TelcoAutomation::V1::Deployment

Returns Required. The deployment to update.

Returns:



897
898
899
900
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 897

class UpdateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. Update mask is used to specify the fields to be overwritten in the deployment resource by the update.

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. Update mask is used to specify the fields to be overwritten in the deployment resource by the update.



897
898
899
900
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 897

class UpdateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end