Class: Google::Cloud::TelcoAutomation::V1::Blueprint
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::Blueprint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
A Blueprint contains a collection of kubernetes resources in the form of YAML files. The file contents of a blueprint are collectively known as package. A blueprint can be a) imported from TNA's public catalog b) modified as per a user's need c) proposed and approved. On approval, a revision of blueprint is created which can be used to create a deployment on Orchestration or Workload Cluster.
Defined Under Namespace
Modules: ApprovalState Classes: LabelsEntry
Instance Attribute Summary collapse
-
#approval_state ⇒ ::Google::Cloud::TelcoAutomation::V1::Blueprint::ApprovalState
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deployment_level ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentLevel
readonly
Output only.
-
#display_name ⇒ ::String
Optional.
-
#files ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::File>
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
The name of the blueprint.
-
#repository ⇒ ::String
readonly
Output only.
-
#revision_create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#revision_id ⇒ ::String
readonly
Output only.
-
#rollback_support ⇒ ::Boolean
readonly
Output only.
-
#source_blueprint ⇒ ::String
Required.
-
#source_provider ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#approval_state ⇒ ::Google::Cloud::TelcoAutomation::V1::Blueprint::ApprovalState (readonly)
Returns Output only. Approval state of the blueprint (DRAFT, PROPOSED, APPROVED).
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Blueprint creation time.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#deployment_level ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentLevel (readonly)
Returns Output only. DeploymentLevel of a blueprint signifies where the blueprint will be applied. e.g. [HYDRATION, SINGLE_DEPLOYMENT, MULTI_DEPLOYMENT].
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#display_name ⇒ ::String
Returns Optional. Human readable name of a Blueprint.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#files ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::File>
Returns Optional. Files present in a blueprint. When invoking UpdateBlueprint API, only the modified files should be included in this. Files that are not included in the update of a blueprint will not be changed.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels are key-value attributes that can be set on a blueprint resource by the user.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#name ⇒ ::String
Returns The name of the blueprint. If unspecified, the name will be autogenerated
from server side. Name of the blueprint must not contain @ character.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#repository ⇒ ::String (readonly)
Returns Output only. Name of the repository where the blueprint files are stored.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#revision_create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp that the revision was created.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#revision_id ⇒ ::String (readonly)
Returns Output only. Immutable. The revision ID of the blueprint. A new revision is committed whenever a blueprint is approved.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#rollback_support ⇒ ::Boolean (readonly)
Returns Output only. Indicates if the deployment created from this blueprint can be rolled back.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#source_blueprint ⇒ ::String
Returns Required. Immutable. The public blueprint ID from which this blueprint was created.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#source_provider ⇒ ::String (readonly)
Returns Output only. Source provider is the author of a public blueprint, from which this blueprint is created.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the blueprint was updated.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 218 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Approval state indicates the state of a Blueprint in its approval # lifecycle. module ApprovalState # Unspecified state. APPROVAL_STATE_UNSPECIFIED = 0 # A blueprint starts in DRAFT state once it is created. All edits are made # to the blueprint in DRAFT state. DRAFT = 1 # When the edits are ready for review, blueprint can be proposed and moves # to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state. PROPOSED = 2 # When a proposed blueprint is approved, it moves to APPROVED state. A new # revision is committed. The latest committed revision can be used to # create a deployment on Orchestration or Workload Cluster. Edits to an # APPROVED blueprint changes its state back to DRAFT. The last committed # revision of a blueprint represents its latest APPROVED state. APPROVED = 3 end end |