Module: Google::Cloud::TelcoAutomation::V1::Blueprint::ApprovalState
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Approval state indicates the state of a Blueprint in its approval lifecycle.
Constant Summary collapse
- APPROVAL_STATE_UNSPECIFIED =
Unspecified state.
0- DRAFT =
A blueprint starts in DRAFT state once it is created. All edits are made to the blueprint in DRAFT state.
1- PROPOSED =
When the edits are ready for review, blueprint can be proposed and moves to PROPOSED state. Edits cannot be made to a blueprint in PROPOSED state.
2- APPROVED =
When a proposed blueprint is approved, it moves to APPROVED state. A new revision is committed. The latest committed revision can be used to create a deployment on Orchestration or Workload Cluster. Edits to an APPROVED blueprint changes its state back to DRAFT. The last committed revision of a blueprint represents its latest APPROVED state.
3