Module: Google::Cloud::TelcoAutomation::V1::Deployment::State
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
State defines which state the current deployment is in.
Constant Summary collapse
- STATE_UNSPECIFIED =
Unspecified state.
0- DRAFT =
A deployment starts in DRAFT state. All edits are made in DRAFT state. A deployment opened for editing after applying will be in draft state, while its prevision revision will be its current applied version.
1- APPLIED =
This state means that the contents (YAML files containing kubernetes resources) of the deployment have been applied to an Orchestration or Workload Cluster. A revision is created when a deployment is applied. This revision will represent the latest view of what is applied on the cluster until the deployment is modified and applied again, which will create a new revision.
2- DELETING =
A deployment in DELETING state has been marked for deletion. Its deletion status can be queried using
ComputeDeploymentStatusAPI. No updates are allowed to a deployment in DELETING state. 3