Class: Google::Cloud::TelcoAutomation::V1::EdgeSlm
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::EdgeSlm
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
EdgeSlm represents an SLM instance which manages the lifecycle of edge components installed on Workload clusters managed by an Orchestration Cluster.
Defined Under Namespace
Modules: State, WorkloadClusterType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Name of the EdgeSlm resource.
-
#orchestration_cluster ⇒ ::String
Immutable.
-
#state ⇒ ::Google::Cloud::TelcoAutomation::V1::EdgeSlm::State
readonly
Output only.
-
#tna_version ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#workload_cluster_type ⇒ ::Google::Cloud::TelcoAutomation::V1::EdgeSlm::WorkloadClusterType
Optional.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Create time stamp.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs. The key and value should contain characters which are UTF-8 compliant and less than 50 characters.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#name ⇒ ::String
Returns Name of the EdgeSlm resource.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#orchestration_cluster ⇒ ::String
Returns Immutable. Reference to the orchestration cluster on which templates for this resources will be applied. This should be of format projects/{project}/locations/{location}/orchestrationClusters/{orchestration_cluster}.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#state ⇒ ::Google::Cloud::TelcoAutomation::V1::EdgeSlm::State (readonly)
Returns Output only. State of the EdgeSlm resource.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#tna_version ⇒ ::String (readonly)
Returns Output only. Provides the active TNA version for this resource.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Update time stamp.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |
#workload_cluster_type ⇒ ::Google::Cloud::TelcoAutomation::V1::EdgeSlm::WorkloadClusterType
Returns Optional. Type of workload cluster for which an EdgeSLM resource is created.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 112 class EdgeSlm include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible states of the resource. module State # Unspecified state. STATE_UNSPECIFIED = 0 # EdgeSlm is being created. CREATING = 1 # EdgeSlm has been created and is ready for use. ACTIVE = 2 # EdgeSlm is being deleted. DELETING = 3 # EdgeSlm encountered an error and is in an indeterministic # state. User can still initiate a delete operation on this state. FAILED = 4 end # Workload clusters supported by TNA. New values will be added to the enum # list as TNA adds supports for new workload clusters in future. module WorkloadClusterType # Unspecified workload cluster. WORKLOAD_CLUSTER_TYPE_UNSPECIFIED = 0 # Workload cluster is a GDCE cluster. GDCE = 1 # Workload cluster is a GKE cluster. GKE = 2 end end |