Module: Google::Cloud::TelcoAutomation::V1::EdgeSlm::State
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Possible states of the resource.
Constant Summary collapse
- STATE_UNSPECIFIED =
Unspecified state.
0- CREATING =
EdgeSlm is being created.
1- ACTIVE =
EdgeSlm has been created and is ready for use.
2- DELETING =
EdgeSlm is being deleted.
3- FAILED =
EdgeSlm encountered an error and is in an indeterministic state. User can still initiate a delete operation on this state.
4