Class: Google::Cloud::TelcoAutomation::V1::GetDeploymentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::GetDeploymentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Request object for GetDeployment.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentView
Optional.
Instance Attribute Details
#name ⇒ ::String
Required. The name of the deployment. Case 1: If the name provided in the request is {deployment_id}@{revision_id}, then the revision with revision_id will be returned. Case 2: If the name provided in the request is {deployment}, then the current state of the deployment is returned.
915 916 917 918 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 915 class GetDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentView
Returns Optional. Defines the type of view of the deployment. When field is not present VIEW_BASIC is considered as default.
915 916 917 918 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 915 class GetDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |