Class: Google::Cloud::TelcoAutomation::V1::ListBlueprintRevisionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::ListBlueprintRevisionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Request object for ListBlueprintRevisions.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
The maximum number of revisions to return per page.
-
#page_token ⇒ ::String
The page token, received from a previous ListBlueprintRevisions call It can be provided to retrieve the subsequent page.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the blueprint to list revisions for.
758 759 760 761 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 758 class ListBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns The maximum number of revisions to return per page.
758 759 760 761 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 758 class ListBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns The page token, received from a previous ListBlueprintRevisions call It can be provided to retrieve the subsequent page.
758 759 760 761 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 758 class ListBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |