Class: Google::Cloud::TelcoAutomation::V1::ListDeploymentRevisionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::ListDeploymentRevisionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Request for listing all revisions of a deployment.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the deployment to list revisions for.
976 977 978 979 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 976 class ListDeploymentRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of revisions to return per page.
976 977 978 979 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 976 class ListDeploymentRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The page token, received from a previous ListDeploymentRevisions call Provide this to retrieve the subsequent page.
976 977 978 979 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 976 class ListDeploymentRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |