Class: Google::Cloud::TelcoAutomation::V1::MasterAuthorizedNetworksConfig
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::MasterAuthorizedNetworksConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Configuration of the Master Authorized Network that support multiple CIDRs
Defined Under Namespace
Classes: CidrBlock
Instance Attribute Summary collapse
Instance Attribute Details
#cidr_blocks ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::MasterAuthorizedNetworksConfig::CidrBlock>
Returns Optional. cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1309 class MasterAuthorizedNetworksConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CidrBlock contains an optional name and one CIDR block. # @!attribute [rw] display_name # @return [::String] # Optional. display_name is an optional field for users to identify CIDR # blocks. # @!attribute [rw] cidr_block # @return [::String] # Optional. cidr_block must be specified in CIDR notation when using # master_authorized_networks_config. Currently, the user could still use # the deprecated man_block field, so this field is currently optional, but # will be required in the future. class CidrBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |