Module: Google::Cloud::TelcoAutomation::V1::OrchestrationCluster::State
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Possible states that the Orchestration Cluster can be in.
Constant Summary collapse
- STATE_UNSPECIFIED =
Unspecified state.
0- CREATING =
OrchestrationCluster is being created.
1- ACTIVE =
OrchestrationCluster has been created and is ready for use.
2- DELETING =
OrchestrationCluster is being deleted.
3- FAILED =
OrchestrationCluster encountered an error and is in an indeterministic state. User can still initiate a delete operation on this state.
4