Class: Google::Cloud::TelcoAutomation::V1::PublicBlueprint
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::PublicBlueprint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
A Blueprint contains a collection of kubernetes resources in the form of YAML files. The file contents of a blueprint are collectively known as package. Public blueprint is a TNA provided blueprint that in present in TNA's public catalog. A user can copy the public blueprint to their private catalog for further modifications.
Instance Attribute Summary collapse
-
#deployment_level ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentLevel
DeploymentLevel of a blueprint signifies where the blueprint will be applied.
-
#description ⇒ ::String
The description of the public blueprint.
-
#display_name ⇒ ::String
The display name of the public blueprint.
-
#name ⇒ ::String
Name of the public blueprint.
-
#rollback_support ⇒ ::Boolean
readonly
Output only.
-
#source_provider ⇒ ::String
Source provider is the author of a public blueprint.
Instance Attribute Details
#deployment_level ⇒ ::Google::Cloud::TelcoAutomation::V1::DeploymentLevel
Returns DeploymentLevel of a blueprint signifies where the blueprint will be applied. e.g. [HYDRATION, SINGLE_DEPLOYMENT, MULTI_DEPLOYMENT].
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns The description of the public blueprint.
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns The display name of the public blueprint.
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the public blueprint.
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollback_support ⇒ ::Boolean (readonly)
Returns Output only. Indicates if the deployment created from this blueprint can be rolled back.
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_provider ⇒ ::String
Returns Source provider is the author of a public blueprint. e.g. Google, vendors.
280 281 282 283 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 280 class PublicBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |