Class: Google::Cloud::TelcoAutomation::V1::SearchBlueprintRevisionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::SearchBlueprintRevisionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Request object for SearchBlueprintRevisions.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#query ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of blueprints revisions to return per page. max page size = 100, default page size = 20.
799 800 801 802 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 799 class SearchBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The page token, received from a previous search call. It can be provided to retrieve the subsequent page.
799 800 801 802 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 799 class SearchBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of parent orchestration cluster resource. Format should be - "projects/{project_id}/locations/{location_name}/orchestrationClusters/{orchestration_cluster}".
799 800 801 802 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 799 class SearchBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::String
Returns Required. Supported queries:
- "" : Lists all revisions across all blueprints.
- "latest=true" : Lists latest revisions across all blueprints.
- "name={name}" : Lists all revisions of blueprint with name {name}.
- "name={name} latest=true": Lists latest revision of blueprint with name {name}.
799 800 801 802 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 799 class SearchBlueprintRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |