Class: Google::Cloud::TelcoAutomation::V1::SearchDeploymentRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::TelcoAutomation::V1::SearchDeploymentRevisionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb
Overview
Response object for SearchDeploymentRevisions.
Instance Attribute Summary collapse
-
#deployments ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Deployment>
The list of requested deployment revisions.
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#deployments ⇒ ::Array<::Google::Cloud::TelcoAutomation::V1::Deployment>
Returns The list of requested deployment revisions.
1031 1032 1033 1034 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1031 class SearchDeploymentRevisionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
1031 1032 1033 1034 |
# File 'proto_docs/google/cloud/telcoautomation/v1/telcoautomation.rb', line 1031 class SearchDeploymentRevisionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |